﻿using ShoeStore.Forms;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace ShoeStore.Forms
{
    public partial class FormStore : Form
    {
        private readonly IStoreRepository _storeRepository;
        private int? _storeId;
        public int Id
        {
            set
            {
                try
                {
                    var store =
                    _storeRepository.ReadStoreById(value);
                    if (store == null)
                    {



                        throw new InvalidDataException(nameof(store));
                    }
                    textBoxAnimalSpecies.Text = store.AnimalSpecies;
                    textBoxAnimalNickName.Text =
                    store.AnimalNickName;
                    numericUpDownAge.Value = store.Age;
                    numericUpDownWeight.Value =
                    (decimal)store.Weight;
                    _storeId = value;
                }
                catch (Exception ex)
                {
                    MessageBox.Show(ex.Message, "Ошибка при получении данных", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    return;
                }
            }
        }
        public FormAnimal(IAnimalRepository storeRepository)
        {
            InitializeComponent();
            _storeRepository = storeRepository ??
            throw new
            ArgumentNullException(nameof(storeRepository));
        }
        private void ButtonSave_Click(object sender, EventArgs e)
        {
            try
            {
                if (string.IsNullOrWhiteSpace(textBoxAnimalSpecies.Text) || string.IsNullOrWhiteSpace(textBoxAnimalNickName.Text))
                {
                    throw new Exception("Имеются незаполненные поля");
                }
                if (_storeId.HasValue)
                {
                    _storeRepository.UpdateAnimal(CreateAnimal(_storeId.Value));
                }
                else
                {
                    _storeRepository.CreateAnimal(CreateAnimal(0));
                }
                Close();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при сохранении",
                MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
        private void ButtonCancel_Click(object sender, EventArgs e) =>
        Close();
        private Animal CreateAnimal(int id) => Animal.CreateEntity(id,
        textBoxAnimalSpecies.Text,
        textBoxAnimalNickName.Text,
        Convert.ToInt32(numericUpDownAge.Value),
        Convert.ToDouble(numericUpDownWeight.Value));
    }
}
